import Swal from "sweetalert2";
import Api from "../helpers/api";
import ramificationMixin from "./ramificationMixin";
import entiteMixin from "./entiteMixin";
import moment from "moment"
export default {
    mixins:[ ramificationMixin,entiteMixin],

    data(){
        return{
            api: new Api(),
            tableData: [],
            selectedItems: [],
            allSelected: false,
            meta: {},
            pageOptions: [10, 50, 100, 200, 500],
            selectedEtablissement: null,
            pagination: {
                itemsPerPage: 50,
                totalPages: 1,
                currentPage: 1,
            },
            sortBy: '',

            fields: [],
            orderBy: '',
            colonnes:[],
            sortOrder: 'desc',
        }
    },
    computed:{
        pages() {
            let pages = Array.from({length: this.pagination.totalPages}, (_, i) => i + 1)
            let currentPage = this.pagination.currentPage
            let visiblePages = 5
            let start = currentPage - Math.floor(visiblePages / 2)
            let end = currentPage + Math.floor(visiblePages / 2)
            if (start < 1) {
                end += 1 - start
                start = 1
            }
            if (end > this.pagination.totalPages) {
                start -= end - this.pagination.totalPages
                end = this.pagination.totalPages
            }
            if (start > 1) {
                pages.splice(0, start - 1, '...')
            }
            if (end < this.pagination.totalPages) {
                pages.splice(end, this.pagination.totalPages - end, '...')
            }
            return pages.slice(start - 1, end)
        }

    },

    methods:{
        formattedNumber(number) {
            if (number != null)
                return number.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
            return 0;
        },
        selectAll() {
            if (this.allSelected === false) {
                this.allSelected = true;
                this.selectedItems = this.tableData.map(data => data.id);
            } else {
                this.allSelected = false;
                this.selectedItems = [];

                // console.log(this.selectedItems);

            }

            //console.log(this.allSelected)
        },
        countHabitsByMateriel(commande) {
            const habitsCount = {};
            commande.hhabits.forEach((depot) => {
                const materielName = depot.materiel.nom;
                if (habitsCount[materielName]) {
                    habitsCount[materielName]++;
                } else {
                    habitsCount[materielName] = 1;
                }
            });
            return habitsCount;
        },

        handleSortBy(){
            var colonne = this.colonnes.find(item => item.text === this.sortBy)
            console.log(colonne)
            this.orderBy = colonne.name
            this.fillTable()
        },
        handleSortOrder(){
            this.fillTable()

        },
        async updateStatus(id, value) {
            this.isLoading =true
           var response = await this.api.put(this.url + "/" + id, {enabled: value})
            if (response.id){
                this.fillTable();
                this.isLoading=false
            }

        },

        confirmDelete(id) {
            Swal.fire({
                title: "Etes-vous sûr ?",
                text: "Vous ne pourrez plus recuper les informations",
                icon: "warning",
                showCancelButton: true,
                confirmButtonColor: "#34c38f",
                cancelButtonColor: "#f46a6a",
                confirmButtonText: "Oui, Supprimer le !",
                cancelButtonText: "Annuler",
            }).then((result) => {
                if (result.value) {

                    this.api.delete(this.url+"/"+id)
                        .then(response => {
                            if(response === true){
                                this.fillTable();
                                Swal.fire("Supprimer!", "Votre ligne a été supprimée.", "success");
                            }
                        })


                }
            });
        },
        bulkDelete() {
            Swal.fire({
                title: "Etes-vous sûr ?",
                text: "Vous ne pourrez plus recuper les informations",
                icon: "warning",
                showCancelButton: true,
                confirmButtonColor: "#34c38f",
                cancelButtonColor: "#f46a6a",
                confirmButtonText: "Oui, Supprimer le !",
                cancelButtonText: "Annuler",
            }).then((result) => {
                if (result.value) {
                    this.selectedItems.forEach(element => {
                        this.api.delete(this.url+"/"+element)
                            .then(response => {
                                if(response === true){
                                    this.fillTable();
                                    Swal.fire("Supprimer!", "Votre ligne a été supprimée.", "success");
                                }
                            })
                    })



                }
            });
        },

        changeElementParPage(val){
            //console.log(val)
            this.pagination.itemsPerPage = val.id;
            this.fillTable();
        },
        filterQuery(){
            this.fields = [];
            this.colonnes.forEach(item => {
                this.fields.push({colonne: item.name, operator: 'like', value: this.searchKey, connector: 'or'})
            })
            if (this.searchKey.length >= 2){
                this.fillTable()
            }else{
                var index = null;
                this.colonnes.forEach(item => {
                    index = this.fields.findIndex((obj) => obj.colonne === item.name);
                    if (index !== -1) {
                        this.fields.splice(index, 1);
                    }
                })
                this.fillTable();

            }
        },
        goToPage(page){
            this.pagination.currentPage = page;
            this.fillTable();
        },
        formatDate(date, format){
            return moment(date).lang('fr').format(format);

        },
        async fillTable() {

            let response = await this.api.listing(this.url, this.fields, this.orderBy, this.sortOrder, this.pagination.itemsPerPage, this.pagination.currentPage)
            this.tableData = response.data
            this.meta = response.meta.total_records;
            this.pagination.totalPages = Math.ceil(response.meta.total_records / this.pagination.itemsPerPage);
            this.isLoading = false;
        },

    },
    mounted() {
        this.selectedEtablissement = this.$store.state.selectedEtablissement

    }

}